@@ -1,6 +1,6 @@
 #' add_osm_groups
 #'
-#' Plots spatially distinct groups of OSM objects in different colours. 
+#' Plots spatially distinct groups of OSM objects in different colours.
 #'
 #' @param map A \code{ggplot2} object to which the grouped objects are to be
 #' added.
@@ -51,7 +51,9 @@
 #' bbox <- get_bbox (c (-0.13, 51.5, -0.11, 51.52))
 #' # Download data using 'extract_osm_objects'
 #' \dontrun{
-#' dat_HP <- extract_osm_objects (key = 'highway', value = 'primary', bbox = bbox)
+#' dat_HP <- extract_osm_objects (key = 'highway',
+#'                                value = 'primary',
+#'                                bbox = bbox)
 #' dat_T <- extract_osm_objects (key = 'tree', bbox = bbox)
 #' dat_BNR <- extract_osm_objects (key = 'building', value = '!residential',
 #' bbox = bbox)
@@ -68,7 +70,7 @@
 #'     map <- add_osm_objects (map, dat_HP, col = "gray70", size = 1)
 #'     add_osm_objects (map, dat_T, col = "green")
 #' }
-#' 
+#'
 #' # Highlight a single region using all objects lying partially inside the
 #' # boundary (via the boundary = 1 argument)
 #' pts <- sp::SpatialPoints (cbind (c (-0.115, -0.125, -0.125, -0.115),
@@ -82,59 +84,66 @@
 #'                        bg = "gray30", boundary = 1)
 #' print_osm_map (map)
 #' }
-#' 
+#'
 #' # Generate random points to serve as group centres
 #' set.seed (2)
 #' ngroups <- 6
 #' x <- bbox [1,1] + runif (ngroups) * diff (bbox [1,])
 #' y <- bbox [2,1] + runif (ngroups) * diff (bbox [2,])
 #' groups <- cbind (x, y)
-#' groups <- apply (groups, 1, function (i) 
-#'               sp::SpatialPoints (matrix (i, nrow = 1, ncol = 2)))
+#' groups <- apply (groups, 1, function (i)
+#'                  sp::SpatialPoints (
+#'                      matrix (i, nrow = 1, ncol = 2)))
 #' # plot a basemap and add groups
 #' map <- bmap ()
 #' cols <- rainbow (length (groups))
 #' \dontrun{
-#' map <- add_osm_groups (map, obj = london$dat_BNR, group = groups, cols = cols)
+#' map <- add_osm_groups (map,
+#'                        obj = london$dat_BNR,
+#'                        group = groups,
+#'                        cols = cols)
 #' cols <- adjust_colours (cols, -0.2)
 #' map <- add_osm_groups (map, obj = london$dat_H, groups = groups, cols = cols)
 #' print_osm_map (map)
-#' 
+#'
 #' # Highlight convex hulls containing groups:
 #' map <- bmap ()
-#' map <- add_osm_groups (map, obj = london$dat_BNR, group = groups, cols = cols,
+#' map <- add_osm_groups (map,
+#'                        obj = london$dat_BNR,
+#'                        group = groups,
+#'                        cols = cols,
 #'                        border_width = 2)
 #' print_osm_map (map)
 #' }
 
 add_osm_groups <- function (map, obj, groups, cols, bg, make_hull = FALSE,
                             boundary = -1, size, shape, border_width = 1,
-                            colmat, rotate)
-{
+                            colmat, rotate) {
+
     # ---------------  sanity checks and warnings  ---------------
     if (missing (map))
-        stop ('map must be supplied')
+        stop ("map must be supplied")
     check_map_arg (map)
     if (missing (obj))
-        stop ('obj must be supplied')
+        stop ("obj must be supplied")
     check_obj_arg (obj)
     groups <- check_groups_arg (groups)
-    if (length (groups) == 1)
-    {
+    if (length (groups) == 1) {
+
         colmat <- FALSE
-        if (missing (bg))
-        {
-            message (paste0 ('Plotting one group only makes sense with bg;',
-                             ' defaulting to gray40'))
-            bg <- 'gray40'
+        if (missing (bg)) {
+
+            message (paste0 ("Plotting one group only makes sense with bg;",
+                             " defaulting to gray40"))
+            bg <- "gray40"
         }
     }
     # ---------- colmat
-    if (!missing (colmat))
-    {
-        colmat <- check_arg (colmat, 'colmat', 'logical')
+    if (!missing (colmat)) {
+
+        colmat <- check_arg (colmat, "colmat", "logical")
         if (is.na (colmat))
-            stop ('colmat can not be coerced to logical', call. = FALSE)
+            stop ("colmat can not be coerced to logical", call. = FALSE)
     }
     # ---------- others
     make_hull <- check_hull_arg (make_hull, groups)
@@ -146,15 +155,15 @@ add_osm_groups <- function (map, obj, groups, cols, bg, make_hull = FALSE,
 
     # Set up group colours
     cmat <- NULL
-    if (!colmat)
-    {
-        if (missing (cols))
-        {
+    if (!colmat) {
+
+        if (missing (cols)) {
+
             cols_default <- group_colours_default (cols, groups, bg)
             cols <- cols_default$cols
         }
-    } else
-    {
+    } else {
+
         cols_colourmat <- group_colours_colourmat (cols, groups, rotate)
         cols <- cols_colourmat$cols
         cmat <- cols_colourmat$cmat
@@ -163,8 +172,8 @@ add_osm_groups <- function (map, obj, groups, cols, bg, make_hull = FALSE,
         bg <- NULL
 
     obj_type <- get_obj_type (obj)
-    if (grepl ('point', obj_type))
-        stop ('add_osm_groups not yet implemented for points')
+    if (grepl ("point", obj_type))
+        stop ("add_osm_groups not yet implemented for points")
 
     # Determine whether any groups are holes - not implemented at present
     if (length (groups) > 1)
@@ -183,13 +192,13 @@ add_osm_groups <- function (map, obj, groups, cols, bg, make_hull = FALSE,
     coords <- get_obj_coords (obj, cent_bdry)
 
     # Get membership of objects within groups
-    if (is.null (bg)) # include all points in groups
-    {
+    if (is.null (bg)) { # include all points in groups
+
         membs <- membs_single_group (groups, coords, obj_trim, cent_bdry)
         xy <- membs$xy
         membs <- membs$membs
-    } else
-    {
+    } else {
+
         if (boundary != 0) # exclude objects outside group boundaries
             membs <- membs_multiple_groups_bdry (coords, boundary)
         else # split groups across boundaries
@@ -205,15 +214,15 @@ add_osm_groups <- function (map, obj, groups, cols, bg, make_hull = FALSE,
 
     if (!missing (bg))
         cols <- c (cols, bg)
-    lon <- lat <- id <- NULL # suppress 'no visible binding' error
+    lon <- lat <- id <- NULL # suppress "no visible binding" error
     aes <- ggplot2::aes (x = lon, y = lat, group = id)
 
-    if (grepl ('polygon', obj_type))
+    if (grepl ("polygon", obj_type))
         map <- map_plus_spPolydf_grps (map, xyflat, aes, cols, size) #nolint
-    else if (grepl ('line', obj_type))
+    else if (grepl ("line", obj_type))
         map <- map_plus_spLinedf_grps (map, xyflat, aes, cols, size, shape) #nolint
-    else if (grepl ('point', obj_type))
-    {
+    else if (grepl ("point", obj_type)) {
+
         # Not implemented yet
     }
 
@@ -225,25 +234,25 @@ add_osm_groups <- function (map, obj, groups, cols, bg, make_hull = FALSE,
 #' check groups argument
 #'
 #' @noRd
-check_groups_arg <- function (groups)
-{
-    if (missing (groups))
-        stop ('groups must be provided', call. = FALSE)
-    if (is.null (groups))
-        stop ('groups must not be NULL', call. = FALSE)
+check_groups_arg <- function (groups) {
 
-    if (is (groups, 'list'))
-    {
-        for (i in seq (groups))
-        {
-            if (is (groups [[i]], 'Spatial'))
+    if (missing (groups))
+        stop ("groups must be provided", call. = FALSE)
+    if (is.null (groups))
+        stop ("groups must not be NULL", call. = FALSE)
+
+    if (is (groups, "list")) {
+
+        for (i in seq (groups)) {
+
+            if (is (groups [[i]], "Spatial"))
                 groups [[i]] <- de_spatial_points (groups [[i]])
             else if (!is.numeric (groups [[i]]))
-                stop ('All groups must be numeric')
+                stop ("All groups must be numeric")
         }
-    } else
-    {
-        if (is (groups, 'Spatial'))
+    } else {
+
+        if (is (groups, "Spatial"))
             groups <- de_spatial_points (groups)
         groups <- list (groups)
     }
@@ -253,30 +262,30 @@ check_groups_arg <- function (groups)
 
 #' get raw coordinates from spatialpoints object
 #' @noRd
-de_spatial_points <- function (x)
-{
-    if (!is (x, 'SpatialPoints'))
-        stop ('All groups must be SpatialPoints objects')
-    slot (x, 'coords')
+de_spatial_points <- function (x) {
+
+    if (!is (x, "SpatialPoints"))
+        stop ("All groups must be SpatialPoints objects")
+    slot (x, "coords")
 }
 
 #' check structure of 'make_hull' arg
 #'
 #' @noRd
-check_hull_arg <- function (make_hull, groups)
-{
-    if (length (make_hull) > length (groups))
-    {
-        warning (paste0 ('make_hull has length > number of groups'))
+check_hull_arg <- function (make_hull, groups) {
+
+    if (length (make_hull) > length (groups)) {
+
+        warning (paste0 ("make_hull has length > number of groups"))
         make_hull <- make_hull [seq (groups)]
-    } else if (length (make_hull) > 1 & length (make_hull) < length (groups))
-    {
-        warning (paste0 ('make_hull should have length 1 or equal to numbers ',
-                         'of groups; using first value only'))
+    } else if (length (make_hull) > 1 & length (make_hull) < length (groups)) {
+
+        warning (paste0 ("make_hull should have length 1 or equal to numbers ",
+                         "of groups; using first value only"))
         make_hull <- make_hull [1]
     }
-    if (!is.list (groups))
-    {
+    if (!is.list (groups)) {
+
         if (length (groups) < 3)
             make_hull <- FALSE
     } else if (max (sapply (groups, length)) < 3) # No groups have > 2 members
@@ -288,25 +297,25 @@ check_hull_arg <- function (make_hull, groups)
 #' default group colours with no colourmat
 #'
 #' @noRd
-group_colours_default <- function (cols, groups, bg)
-{
+group_colours_default <- function (cols, groups, bg) {
+
     if (missing (cols))
         cols <- rainbow (length (groups))
     else if (length (cols) < length (groups))
         cols <- rep (cols, length.out = length (groups))
 
-    ret <- list ('cols' = cols)
-    if (length (groups) == 1 & missing (bg))
-    {
-        warning ('There is only one group; using default bg')
-        if (cols [1] != 'gray40')
-            bg <- 'gray40'
-        else
-            bg <- 'white'
+    ret <- list ("cols" = cols)
+    if (length (groups) == 1 & missing (bg)) {
 
-        ret ['bg'] <- bg
+        warning ("There is only one group; using default bg")
+        if (cols [1] != "gray40")
+            bg <- "gray40"
+        else
+            bg <- "white"
+
+        ret ["bg"] <- bg
     } else if (!missing (bg))
-        ret ['bg'] <- bg
+        ret ["bg"] <- bg
 
     return (ret)
 }
@@ -314,8 +323,8 @@ group_colours_default <- function (cols, groups, bg)
 #' group colours from colourmat
 #'
 #' @noRd
-group_colours_colourmat <- function (cols, groups, rotate)
-{
+group_colours_colourmat <- function (cols, groups, rotate) {
+
     if (missing (cols))
         cols <- rainbow (4)
     else if (length (cols) < 4)
@@ -323,8 +332,8 @@ group_colours_colourmat <- function (cols, groups, rotate)
     ncols <- 20
     if (missing (rotate))
         cmat <- colour_mat (ncols, cols = cols)
-    else
-    {
+    else {
+
         if (!is.numeric (rotate))
             rotate <- 0
         cmat <- colour_mat (ncols, cols = cols, rotate)
@@ -333,7 +342,7 @@ group_colours_colourmat <- function (cols, groups, rotate)
     # cols is then a vector of colours to be filled by matching group
     # centroids to relative positions within cmat
 
-    return (list ('cols' = cols, 'cmat' = cmat))
+    return (list ("cols" = cols, "cmat" = cmat))
 }
 
 #' identify groups which are holes in other groups
@@ -342,33 +351,33 @@ group_colours_colourmat <- function (cols, groups, rotate)
 #' form.
 #'
 #' @noRd
-groups_are_holes <- function (groups)
-{
+groups_are_holes <- function (groups) {
+
     holes <- rep (FALSE, length (groups))
     group_pairs <- combn (length (groups), 2)
-    for (i in seq (ncol (group_pairs)))
-    {
-        n1 <- length (groups [[group_pairs [1, i] ]])
-        n2 <- length (groups [[group_pairs [2, i] ]])
-        if (n1 > 2 & n2 > 2) # otherwise can't be a hole
-        {
-            x1 <- sp::coordinates (groups [[group_pairs [1, i] ]]) [, 1]
-            y1 <- sp::coordinates (groups [[group_pairs [1, i] ]]) [, 2]
+    for (i in seq (ncol (group_pairs))) {
+
+        n1 <- length (groups [[group_pairs [1, i] ]]) # nolint
+        n2 <- length (groups [[group_pairs [2, i] ]]) # nolint
+        if (n1 > 2 & n2 > 2) { # otherwise can't be a hole
+
+            x1 <- sp::coordinates (groups [[group_pairs [1, i] ]]) [, 1] # nolint
+            y1 <- sp::coordinates (groups [[group_pairs [1, i] ]]) [, 2] # nolint
             indx <- which (!duplicated (cbind (x1, y1)))
             x1 <- x1 [indx]
             y1 <- y1 [indx]
-            xy1 <- spatstat::ppp (x1, y1,
-                                  xrange = range (x1), yrange = range (y1))
-            ch1 <- spatstat::convexhull (xy1)
+            xy1 <- spatstat.geom::ppp (x1, y1,
+                                       xrange = range (x1), yrange = range (y1))
+            ch1 <- spatstat.geom::convexhull (xy1)
             bdry1 <- cbind (ch1$bdry[[1]]$x, ch1$bdry[[1]]$y)
-            x2 <- sp::coordinates (groups [[group_pairs [2, i] ]]) [, 1]
-            y2 <- sp::coordinates (groups [[group_pairs [2, i] ]]) [, 2]
+            x2 <- sp::coordinates (groups [[group_pairs [2, i] ]]) [, 1] # nolint
+            y2 <- sp::coordinates (groups [[group_pairs [2, i] ]]) [, 2] # nolint
             indx <- which (!duplicated (cbind (x2, y2)))
             x2 <- x2 [indx]
             y2 <- y2 [indx]
-            xy2 <- spatstat::ppp (x2, y2,
-                                  xrange = range (x2), yrange = range (y2))
-            ch2 <- spatstat::convexhull (xy2)
+            xy2 <- spatstat.geom::ppp (x2, y2,
+                                       xrange = range (x2), yrange = range (y2))
+            ch2 <- spatstat.geom::convexhull (xy2)
             bdry2 <- cbind (ch2$bdry[[1]]$x, ch2$bdry[[1]]$y)
 
             indx <- sapply (bdry1, function (x)
@@ -392,19 +401,19 @@ groups_are_holes <- function (groups)
 #' @note This has to be modified for points!
 #'
 #' @noRd
-trim_obj_to_map <- function (obj, map, obj_type)
-{
+trim_obj_to_map <- function (obj, map, obj_type) {
+
     xrange <- map$coordinates$limits$x
     yrange <- map$coordinates$limits$y
 
-    if (grepl ('point', obj_type))
-    {
+    if (grepl ("point", obj_type)) {
+
         indx <- which (obj [, 1] > xrange [1] & obj [, 2] > yrange [1] &
                        obj [, 1] < xrange [2] & obj [, 2] < yrange [2])
         obj <- obj [indx, ]
         xy_mn <- obj
-    } else
-    {
+    } else {
+
         # remove objects that extend beyond map:
         #xylims <- lapply (obj, function (i)
         #                  c (apply (i, 2, min), apply (i, 2, max)))
@@ -422,8 +431,8 @@ trim_obj_to_map <- function (obj, map, obj_type)
                                           i [, 2] < yrange [2])
                            if (length (indx) < 2)
                                ret <- NULL
-                           else if (length (indx) < nrow (i))
-                           {
+                           else if (length (indx) < nrow (i)) {
+
                                ret <- i [indx, ]
                                if (grepl ("polygon", obj_type))
                                    ret <- rbind (ret, i [1, ])
@@ -440,7 +449,7 @@ trim_obj_to_map <- function (obj, map, obj_type)
         xy_mn <- do.call (rbind, lapply (obj, function (x) colMeans (x)))
     }
 
-    return (list ('obj' = obj, 'xy_mn' = xy_mn))
+    return (list ("obj" = obj, "xy_mn" = xy_mn))
 }
 
 #' Get centroids and boundaries of group objects
@@ -451,37 +460,39 @@ trim_obj_to_map <- function (obj, map, obj_type)
 #' 2. boundaries list of enclosing polygons, creating convex hulls if necessary.
 #'
 #' @noRd
-group_centroids_bdrys <- function (groups, make_hull, cols, cmat, obj_trim, map)
-{
+group_centroids_bdrys <- function (groups, make_hull, cols,
+                                   cmat, obj_trim, map) {
+
     boundaries <- list ()
     grp_centroids <- list ()
 
-    for (i in seq (groups))
-    {
-        if ( (length (make_hull) == 1 & make_hull) |
-            (length (make_hull) > 1 & make_hull [i]))
-        {
+    for (i in seq (groups)) {
+
+        if ((length (make_hull) == 1 & make_hull) |
+            (length (make_hull) > 1 & make_hull [i])) {
+
             x <- groups [[i]] [, 1]
             y <- groups [[i]] [, 2]
-            if (length (x) > 2)
-            {
-                xy <- spatstat::ppp (x, y,
-                                     xrange = range (x), yrange = range (y))
-                ch <- spatstat::convexhull (xy)
+            if (length (x) > 2) {
+
+                xy <- spatstat.geom::ppp (x, y,
+                                          xrange = range (x),
+                                          yrange = range (y))
+                ch <- spatstat.geom::convexhull (xy)
                 bdry <- cbind (ch$bdry[[1]]$x, ch$bdry[[1]]$y)
-            } else
-            {
+            } else {
+
                 bdry <- groups [[i]]
             }
-        } else
-        {
+        } else {
+
             bdry <- groups [[i]]
         }
         if (!is.matrix (bdry))
             bdry <- matrix (bdry, nrow = 1)
 
-        if (nrow (bdry) > 1) # otherwise group is obviously a single point
-        {
+        if (nrow (bdry) > 1) { # otherwise group is obviously a single point
+
             bdry <- rbind (bdry, bdry [1, ]) #enclose bdry back to 1st point
             # The next 4 lines are only used if is.null (bg)
             indx <- sp::point.in.polygon (obj_trim$xy_mn [, 1],
@@ -489,19 +500,19 @@ group_centroids_bdrys <- function (groups, make_hull, cols, cmat, obj_trim, map)
                                           bdry [, 1], bdry [, 2])
             indx <- which (indx > 0) # see below for point.in.polygon values
             grp_centroids [[i]] <- obj_trim$xy_mn [indx, ]
-        } else
-        {
+        } else {
+
             grp_centroids [[i]] <- bdry
             # indx closest point to bdry
-            d <- sqrt ( (obj_trim$xmn - bdry [1]) ^ 2 +
+            d <- sqrt ((obj_trim$xmn - bdry [1]) ^ 2 +
                        (obj_trim$ymn - bdry [2]) ^ 2)
             indx <- which.min (d)
         }
 
         boundaries [[i]] <- bdry
 
-        if (!is.null (cmat))
-        {
+        if (!is.null (cmat)) {
+
             # Then get colour from colour.mat
             xrange <- map$coordinates$limits$x
             yrange <- map$coordinates$limits$y
@@ -517,8 +528,8 @@ group_centroids_bdrys <- function (groups, make_hull, cols, cmat, obj_trim, map)
         }
     }
 
-    return (list ('bdry' = boundaries, 'grp_centroids' = grp_centroids,
-                  'cols' = cols))
+    return (list ("bdry" = boundaries, "grp_centroids" = grp_centroids,
+                  "cols" = cols))
 }
 
 #' get coordinates of each obj to be plotted
@@ -528,12 +539,12 @@ group_centroids_bdrys <- function (groups, make_hull, cols, cmat, obj_trim, map)
 #' sufficient size
 #'
 #' @noRd
-get_obj_coords <- function (obj, cent_bdry)
-{
-    coords <- lapply (obj, function (i)
-                      {
-                          pins <- lapply (cent_bdry$bdry, function (j)
-                                          {
+get_obj_coords <- function (obj, cent_bdry) {
+
+    coords <- lapply (obj, function (i) {
+
+                          pins <- lapply (cent_bdry$bdry, function (j) {
+
                                               if (nrow (j) > 2)
                                                   sp::point.in.polygon (
                                                         i [, 1], i [, 2],
@@ -551,17 +562,17 @@ get_obj_coords <- function (obj, cent_bdry)
 #' get members of single group
 #'
 #' @noRd
-membs_single_group <- function (groups, coords, obj_trim, cent_bdry)
-{
-    membs <- sapply (coords, function (i)
-                     {
+membs_single_group <- function (groups, coords, obj_trim, cent_bdry) {
+
+    membs <- sapply (coords, function (i) {
+
                          temp <- i [, 3:ncol (i), drop = FALSE]
                          temp [temp > 1] <- 1
                          n <- colSums (temp)
                          if (max (n) < 3) # must have > 2 elements in group
                              n <- 0
-                         else
-                         {
+                         else {
+
                              indx <- which (n == max (n))
                              n <- indx [ceiling (runif (1) * length (indx))]
                          }
@@ -571,18 +582,18 @@ membs_single_group <- function (groups, coords, obj_trim, cent_bdry)
     x0 <- obj_trim$xy_mn [indx, 1]
     y0 <- obj_trim$xy_mn [indx, 2]
     dists <- array (NA, dim = c (length (indx), length (groups)))
-    for (i in seq (groups))
-    {
+    for (i in seq (groups)) {
+
         ng <- dim (cent_bdry$grp_centroids [[i]]) [1]
-        if (ng > 0)
-        {
+        if (ng > 0) {
+
             x0mat <- array (x0, dim = c(length (x0), ng))
             y0mat <- array (y0, dim = c(length (y0), ng))
             xmat <- t (array (cent_bdry$grp_centroids [[i]] [, 1],
                               dim = c(ng, length (x0))))
             ymat <- t (array (cent_bdry$grp_centroids [[i]] [, 2],
                               dim = c(ng, length (x0))))
-            dg <- sqrt ( (xmat - x0mat) ^ 2 + (ymat - y0mat) ^ 2)
+            dg <- sqrt ((xmat - x0mat) ^ 2 + (ymat - y0mat) ^ 2)
             # Then the minimum distance for each stray object to any object
             # in group [i]:
             dists [, i] <- apply (dg, 1, min)
@@ -593,7 +604,7 @@ membs_single_group <- function (groups, coords, obj_trim, cent_bdry)
     membs [indx] <- apply (dists, 1, which.min)
     xy <- lapply (coords, function (i) i [, 1:2, drop = FALSE])
 
-    return (list ('membs' = membs, 'xy' = xy))
+    return (list ("membs" = membs, "xy" = xy))
 }
 
 #' get members of multiple groups with boundary
@@ -602,16 +613,16 @@ membs_single_group <- function (groups, coords, obj_trim, cent_bdry)
 #' objects to group#0
 #'
 #' @noRd
-membs_multiple_groups_bdry <- function (coords, boundary)
-{
+membs_multiple_groups_bdry <- function (coords, boundary) {
+
     xy <- lapply (coords, function (i) i [, 1:2, drop = FALSE])
-    membs <- lapply (coords, function (i)
-                     {
+    membs <- lapply (coords, function (i) {
+
                          temp <- i [, 3:ncol (i), drop = FALSE]
                          temp [temp > 1] <- 1
                          n <- colSums (temp)
-                         if (boundary < 0)
-                         {
+                         if (boundary < 0) {
+
                              if (max (n) < nrow (temp))
                                  n <- 0
                              else
@@ -623,7 +634,7 @@ membs_multiple_groups_bdry <- function (coords, boundary)
                          return (n)
                      })
 
-    return (list ('membs' = membs, 'xy' = xy))
+    return (list ("membs" = membs, "xy" = xy))
 }
 
 #' get members of multiple groups without boundary
@@ -632,10 +643,10 @@ membs_multiple_groups_bdry <- function (coords, boundary)
 #' coords and thus requiring an explicit loop. TODO: Rcpp this?
 #'
 #' @noRd
-membs_multiple_groups <- function (coords)
-{
-    split_objs <- sapply (coords, function (i)
-                          {
+membs_multiple_groups <- function (coords) {
+
+    split_objs <- sapply (coords, function (i) {
+
                               temp <- i [, 3:ncol (i), drop = FALSE]
                               temp [temp > 1] <- 1
                               n <- colSums (temp)
@@ -649,36 +660,36 @@ membs_multiple_groups <- function (coords)
     # Then split coords into 2 lists, one for non-split objects and one
     # containing those listed in split_objs
     coords_split <- coords [split_objs]
-    coords <- coords [-split_objs] 
+    coords <- coords [-split_objs]
     # Then make new lists of xy and memberships by spliting objects in
     # coords_split. These lists are of unknown length, requiring an
     # unsightly double loop.
     xy <- list ()
     membs <- NULL
-    for (i in coords_split)
-    {
+    for (i in coords_split) {
+
         temp <- i [, 3:ncol (i), drop = FALSE]
         temp [temp > 1] <- 1
         n <- colSums (temp)
-        if (max (n) < 3)
-        {
+        if (max (n) < 3) {
+
             xy [[length (xy) + 1]] <- i [, 1:2]
             membs <- c (membs, 0)
-        } else
-        {
+        } else {
+
             # Allow for multiple group memberships
             indx_i <- which (n > 2)
-            for (j in indx_i)
-            {
+            for (j in indx_i) {
+
                 indx_j <- which (temp [, j] == 1)
-                if (length (indx_j) > 2)
-                {
+                if (length (indx_j) > 2) {
+
                     xy [[length (xy) + 1]] <- i [indx_j, 1:2]
                     membs <- c (membs, j)
                 }
                 indx_j <- which (temp [, j] == 0)
-                if (length (indx_j) > 2)
-                {
+                if (length (indx_j) > 2) {
+
                     xy [[length (xy) + 1]] <- i [indx_j, 1:2]
                     membs <- c (membs, 0)
                 }
@@ -687,8 +698,8 @@ membs_multiple_groups <- function (coords)
     } # end for i
     # Then add the non-split groups
     xy <- c (xy, lapply (coords, function (i) i [, 1:2]))
-    membs2 <- sapply (coords, function (i)
-                      {
+    membs2 <- sapply (coords, function (i) {
+
                           temp <- i [, 3:ncol (i), drop = FALSE]
                           temp [temp > 1] <- 1
                           n <- colSums (temp)
@@ -700,7 +711,7 @@ membs_multiple_groups <- function (coords)
                       })
     membs <- c (membs, membs2)
 
-    return (list ('membs' = membs, 'xy' = xy))
+    return (list ("membs" = membs, "xy" = xy))
 }
 
 #' cbind membs to xy so that membs maps straight onto cols
@@ -710,12 +721,12 @@ membs_multiple_groups <- function (coords)
 #' duplicate row.names.
 #'
 #' @noRd
-cbind_membs_xy <- function (membs, xy)
-{
+cbind_membs_xy <- function (membs, xy) {
+
     xym <- mapply ("cbind", xy, membs, SIMPLIFY = FALSE)
 
-    for (i in seq (xym))
-    {
+    for (i in seq (xym)) {
+
         rownames (xym [[i]]) <- NULL
         xym [[i]] <- data.frame (cbind (i, xym [[i]]))
         names (xym [[i]]) <- c ("id", "lon", "lat", "col")
@@ -727,8 +738,8 @@ cbind_membs_xy <- function (membs, xy)
 #' add SpatialPolygonsDataFrame to map
 #'
 #' @noRd
-map_plus_spPolydf_grps <- function (map, xy, aes, cols, size) #nolint
-{
+map_plus_spPolydf_grps <- function (map, xy, aes, cols, size) { #nolint
+
     if (missing (size))
         size <- 0
     else if (!is.numeric (size))
@@ -741,8 +752,8 @@ map_plus_spPolydf_grps <- function (map, xy, aes, cols, size) #nolint
 #' add SpatialLinesDataFrame to map
 #'
 #' @noRd
-map_plus_spLinedf_grps <- function (map, xyflat, aes, cols, size, shape) #nolint
-{
+map_plus_spLinedf_grps <- function (map, xyflat, aes, cols, size, shape) { #nolint
+
     if (missing (size))
         size <- 0.5
     else if (!is.numeric (size))
@@ -761,28 +772,28 @@ map_plus_spLinedf_grps <- function (map, xyflat, aes, cols, size, shape) #nolint
 #' draw convex hulls around groups on map
 #'
 #' @noRd
-map_plus_hulls <- function (map, border_width = 1, groups, xyflat, cols)
-{
+map_plus_hulls <- function (map, border_width = 1, groups, xyflat, cols) {
+
 
     id <- NULL # suppress R CMD check note for aes (..,`group = id`) below
     if (!is.numeric (border_width))
         return (map)
 
     bdry <- list ()
-    for (i in seq (groups))
-    {
+    for (i in seq (groups)) {
+
         indx <- which (xyflat$col == i) # col = group membership
-        if (length (indx) > 1)
-        {
+        if (length (indx) > 1) {
+
             x <- xyflat$lon [indx]
             y <- xyflat$lat [indx]
             indx <- which (!duplicated (cbind (x, y)))
             x <- x [indx]
             y <- y [indx]
             if (length (x) > 2) {
-                xy2 <- spatstat::ppp (x, y, xrange = range (x),
-                                      yrange = range (y))
-                ch <- spatstat::convexhull (xy2)
+                xy2 <- spatstat.geom::ppp (x, y, xrange = range (x),
+                                           yrange = range (y))
+                ch <- spatstat.geom::convexhull (xy2)
                 bdry [[i]] <- cbind (i, ch$bdry[[1]]$x, ch$bdry[[1]]$y)
             }
         }
