@@ -3,8 +3,8 @@
 #' Makes an entire OSM map for the given bbox using the submitted data, or by
 #' downloading data if none submitted. This is a convenience function enabling
 #' an entire map to be produced according to the graphical format specified with
-#' the \code{structures} argument.  
-#' 
+#' the \code{structures} argument.
+#'
 #' @param bbox The bounding box for the map.  A 2-by-2 matrix of 4 elements with
 #' columns of min and max values, and rows of x and y values.  If \code{NULL},
 #' \code{bbox} is taken from the largest extent of OSM objects in
@@ -17,14 +17,14 @@
 #' returned from \code{\link{osm_structures}}, and potentially modified to alter
 #' lists of structures to be plotted, and their associated colours. Objects are
 #' overlaid on plot according to the order given in \code{structures}.
-#' @param dat_prefix Prefix for data structures (default \code{dat_}). Final data
-#' structures are created by appending the suffixes from
+#' @param dat_prefix Prefix for data structures (default \code{dat_}). Final
+#' data structures are created by appending the suffixes from
 #' \code{\link{osm_structures}}.
-#' @return List of two components: 
+#' @return List of two components:
 #' \enumerate{
 #'   \item List of OSM structures each as
 #'      \code{Spatial(Points/Lines/Polygons)DataFrame} and appended to
-#'      \code{osm_data} (which is \code{NULL} by default), and 
+#'      \code{osm_data} (which is \code{NULL} by default), and
 #'   \item The \code{map} as a \code{ggplot2} object
 #' }
 #' @export
@@ -36,8 +36,8 @@
 #' @seealso \code{\link{osm_basemap}}, \code{\link{add_osm_objects}}.
 #'
 #' @examples
-#' structures <- c ('highway', 'park')
-#' structs <- osm_structures (structures = structures, col_scheme = 'light')
+#' structures <- c ("highway", "park")
+#' structs <- osm_structures (structures = structures, col_scheme = "light")
 #' # make_osm_map returns potentially modified list of data using the provided
 #' # 'london' data for highways and parks.
 #' dat <- make_osm_map (osm_data = london, structures = structs)
@@ -48,22 +48,22 @@
 #' print_osm_map (dat$map)
 #' }
 make_osm_map <- function (bbox, osm_data,
-                          structures = osm_structures (), dat_prefix = 'dat_')
-{
+                          structures = osm_structures (), dat_prefix = "dat_") {
+
     if (missing (bbox))
         bbox <- get_bbox_from_data (osm_data)
 
     sfx <- structures$suffix [1:(nrow (structures) - 1)]
-    if (missing (osm_data))
-    {
+    if (missing (osm_data)) {
+
         structs_new <- seq (nrow (structures) - 1)
         osm_data <- list ()
     } else
         structs_new <- which (!sapply (sfx, function (i)
                            any (paste0 (dat_prefix, i) %in% names (osm_data))))
 
-    if (length (structs_new) > 0)
-    {
+    if (length (structs_new) > 0) {
+
         md <- get_missing_osm_data (osm_data, structures [structs_new, ],
                                     bbox, dat_prefix)
 
@@ -73,13 +73,13 @@ make_osm_map <- function (bbox, osm_data,
     }
     ns <- nrow (structures) - 1 # last row is background
     if (ns == 0)
-        stop ('Downloads contain no data')
+        stop ("Downloads contain no data")
 
-    bg <- structures$col [structures$structure == 'background']
+    bg <- structures$col [structures$structure == "background"]
     map <- osm_basemap (bbox = bbox, bg = bg)
-    for (i in seq (ns))
-    {
-        obji <- paste0 ('dat_', structures$suffix [i])
+    for (i in seq (ns)) {
+
+        obji <- paste0 ("dat_", structures$suffix [i])
         map <- add_osm_objects (map, osm_data [[obji]],
                                 col = structures$cols [i])
     }
@@ -87,26 +87,27 @@ make_osm_map <- function (bbox, osm_data,
     list (osm_data = osm_data, map = map)
 }
 
-get_bbox_from_data <- function (osm_data)
-{
+get_bbox_from_data <- function (osm_data) {
+
     if (missing (osm_data))
-        stop ('Either bounding box or osm_data must be given')
+        stop ("Either bounding box or osm_data must be given")
     bbox <- matrix (c (Inf, Inf, -Inf, -Inf), nrow = 2, ncol = 2)
-    rownames (bbox) <- c ('x', 'y')
-    sp_classes <- c ('SpatialLinesDataFrame', 'SpatialPolygonsDataFrame',
-                  'SpatialPointsDataFrame')
-    for (i in osm_data)
-    {
-        if (is (i, 'sf'))
-        {
-            bbi <- attr (i$geometry, 'bbox')
+    rownames (bbox) <- c ("x", "y")
+    sp_classes <- c ("SpatialLinesDataFrame",
+                     "SpatialPolygonsDataFrame",
+                     "SpatialPointsDataFrame")
+    for (i in osm_data) {
+
+        if (is (i, "sf")) {
+
+            bbi <- attr (i$geometry, "bbox")
             if (bbi [1] < bbox [1, 1]) bbox [1, 1] <- bbi [1]
             if (bbi [2] < bbox [2, 1]) bbox [2, 1] <- bbi [2]
             if (bbi [1] > bbox [1, 2]) bbox [1, 2] <- bbi [1]
             if (bbi [2] > bbox [2, 2]) bbox [2, 2] <- bbi [2]
-        } else if (any (class (i) %in% sp_classes))
-        {
-            bbi <- slot (i, 'bbox')
+        } else if (any (class (i) %in% sp_classes)) {
+
+            bbi <- slot (i, "bbox")
             if (bbi [1, 1] < bbox [1, 1]) bbox [1, 1] <- bbi [1, 1]
             if (bbi [2, 1] < bbox [2, 1]) bbox [2, 1] <- bbi [2, 1]
             if (bbi [1, 2] > bbox [1, 2]) bbox [1, 2] <- bbi [1, 2]
@@ -117,15 +118,15 @@ get_bbox_from_data <- function (osm_data)
     return (bbox)
 }
 
-get_missing_osm_data <- function (osm_data, structures, bbox, dat_prefix)
-{
-    cat ('Downloading and extracting OSM data for',
-         nrow (structures), 'structures ...\n')
+get_missing_osm_data <- function (osm_data, structures, bbox, dat_prefix) {
+
+    cat ("Downloading and extracting OSM data for",
+         nrow (structures), "structures ...\n")
     pb <- txtProgressBar (max = 1, style = 3)
     t0 <- proc.time ()
     indx <- NULL
-    for (i in seq (nrow (structures)))
-    {
+    for (i in seq (nrow (structures))) {
+
         if (structures$value [i] == "")
             dat <- extract_osm_objects (key = structures$key [i],
                                         bbox = bbox)
@@ -134,8 +135,8 @@ get_missing_osm_data <- function (osm_data, structures, bbox, dat_prefix)
                                         value = structures$value [i],
                                         bbox = bbox)
 
-        if (nrow (dat) > 0)
-        {
+        if (nrow (dat) > 0) {
+
             fname <- paste0 (dat_prefix, structures$suffix [i])
             assign (fname, dat)
             osm_data [[fname]] <- get (fname)
@@ -144,7 +145,7 @@ get_missing_osm_data <- function (osm_data, structures, bbox, dat_prefix)
         setTxtProgressBar(pb, i / nrow (structures))
     }
     close (pb)
-    cat ('That took ', (proc.time () - t0)[3], 's\n', sep = '')
+    cat ("That took ", (proc.time () - t0)[3], "s\n", sep = "")
 
-    list ('indx' = indx, 'osm_data' = osm_data)
+    list ("indx" = indx, "osm_data" = osm_data)
 }
