@@ -15,12 +15,12 @@
 #' This function is primarily used in \code{extract_highways}.
 #'
 #' @noRd
-order_lines <- function (xy)
-{
+order_lines <- function (xy) {
+
     xy_ord <- list (xy [[1]])
     xy [[1]] <- NULL
-    while (length (xy) > 0)
-    {
+    while (length (xy) > 0) {
+
         ex <- extend_ord_list (xy, xy_ord)
         xy <- ex$xy
         xy_ord <- ex$xy_ord
@@ -29,18 +29,18 @@ order_lines <- function (xy)
     return (xy_ord)
 }
 
-extend_ord_list <- function (xy, xy_ord)
-{
+extend_ord_list <- function (xy, xy_ord) {
+
     fn <- "head"
     ordi <- which_ord (xy_ord, xy, fn)
-    if (ordi == 0)
-    {
+    if (ordi == 0) {
+
         fn <- "tail"
         ordi <- which_ord (xy_ord, xy, fn)
     }
 
-    if (ordi > 0)
-    {
+    if (ordi > 0) {
+
         xy_ordi <- xy_ord [[ordi]]
         # xy_ordi is element of xy_ord that has either the head or tail of xy
 
@@ -50,13 +50,13 @@ extend_ord_list <- function (xy, xy_ord)
         xtmp <- xy [[xyi]]
         xy [[xyi]] <- NULL
         xy_ord [[ordi]] <- rbind_xy (xtmp, xy_ordi)
-    } else # no join so add first element of xy to xy_ord_list
-    {
+    } else { # no join so add first element of xy to xy_ord_list
+
         xy_ord [[length (xy_ord) + 1]] <- xy [[1]]
         xy [[1]] <- NULL
     }
 
-    return (list ('xy' = xy, 'xy_ord' = xy_ord))
+    return (list ("xy" = xy, "xy_ord" = xy_ord))
 }
 
 # which element of xy_ord contains head or tail element of any component of xy.
@@ -65,8 +65,8 @@ extend_ord_list <- function (xy, xy_ord)
 # added to.
 #
 # @return single int index into xy_ord
-which_ord <- function (xy_ord, xy, fn = 'head')
-{
+which_ord <- function (xy_ord, xy, fn = "head") {
+
     max (0, which (vapply (xy_ord, function (i)
                            max (0, which_xy (i, xy = xy, fn = fn)),
                            numeric (1)) > 0))
@@ -75,8 +75,8 @@ which_ord <- function (xy_ord, xy, fn = 'head')
 # which element of xy has head or tail of xy_ord [[i]]
 #
 # @return logical vector same length as xy
-which_xy <- function (xy, xy_ordi, fn = 'head')
-{
+which_xy <- function (xy, xy_ordi, fn = "head") {
+
     vapply (xy, function (i)
             do.call (fn, list (rownames (xy_ordi), 1)) %in% rownames (i),
             logical (1))
@@ -87,8 +87,8 @@ which_xy <- function (xy, xy_ordi, fn = 'head')
 #' rbind xy to xy_ordi, flipping both where necessary
 #'
 #' @noRd
-rbind_xy <- function (xy, xy_ord)
-{
+rbind_xy <- function (xy, xy_ord) {
+
     if (head (rownames (xy_ord), 1) %in% rownames (xy))
         xy_ord <- apply (xy_ord, 2, rev) # flip to rbind at bottom
     if (tail (rownames (xy), 1) %in% rownames (xy_ord))
