@@ -8,7 +8,7 @@
 #' passed to \code{\link{make_osm_map}} to automate map production.
 #'
 #' @param structures The vector of types of structures (defaults listed in
-#' \code{\link{extract_osm_objects}}).  
+#' \code{\link{extract_osm_objects}}).
 #' @param col_scheme Colour scheme for the plot (current options include
 #' \code{dark} and \code{light}).
 #' @return \code{data.frame} of structures, \code{key-value} pairs,
@@ -22,18 +22,19 @@
 #' # Default structures:
 #' osm_structures ()
 #' # user-defined structures:
-#' structures <- c ('highway', 'park', 'ameniiy', 'tree')
-#' structs <- osm_structures (structures = structures, col_scheme = 'light')
+#' structures <- c ("highway", "park", "ameniiy", "tree")
+#' structs <- osm_structures (structures = structures, col_scheme = "light")
 #' # make_osm_map returns potentially modified list of data
 #' \dontrun{
 #' dat <- make_osm_map (osm_data = london, structures = structs)
 #' # map contains updated $osm_data and actual map in $map
 #' print_osm_map (dat$map)
 #' }
-osm_structures <- function (structures = c ('building', 'amenity', 'waterway',
-                         'grass', 'natural', 'park', 'highway', 'boundary',
-                         'tree'), col_scheme = 'dark')
-{
+osm_structures <- function (structures = c ("building", "amenity", "waterway",
+                                            "grass", "natural", "park",
+                                            "highway", "boundary", "tree"),
+                            col_scheme = "dark") {
+
     kv <- get_key_vals (structures) # key-val pairs
 
     # Get suffixes for naming data objects
@@ -45,9 +46,9 @@ osm_structures <- function (structures = c ('building', 'amenity', 'waterway',
     suffixes <- extend_suffixes (lettrs, structures, indx_in, indx_out)
 
     scheme_cols <- NULL
-    if (col_scheme == 'dark')
+    if (col_scheme == "dark")
         scheme_cols <- get_dark_cols ()
-    else if (col_scheme == 'light')
+    else if (col_scheme == "light")
         scheme_cols <- get_light_cols ()
 
     if (!is.null (scheme_cols))
@@ -55,40 +56,40 @@ osm_structures <- function (structures = c ('building', 'amenity', 'waterway',
 
     # Then add row to designate background colour (this has to be done prior to
     # data.frame construction, because cols are converted there to factors):
-    structures <- c (structures, 'background')
-    kv$keys <- c (kv$keys, '')
-    kv$values <- c (kv$values, '')
-    suffixes <- c (suffixes, '')
+    structures <- c (structures, "background")
+    kv$keys <- c (kv$keys, "")
+    kv$values <- c (kv$values, "")
+    suffixes <- c (suffixes, "")
     cols <- c (cols, scheme_cols$col_bg)
 
     dat <- data.frame (cbind (structures, kv$keys, kv$values, suffixes, cols),
                        stringsAsFactors = FALSE,
                        row.names = seq (length (kv$keys)))
-    names (dat) <- c ('structure', 'key', 'value', 'suffix', 'cols')
+    names (dat) <- c ("structure", "key", "value", "suffix", "cols")
     return (dat)
 }
 
-get_key_vals <- function (structures)
-{
+get_key_vals <- function (structures) {
+
     keys <- structures
-    values <- rep ('', length (keys))
-    val_list <- c ('grass', 'park', 'tree', 'water')
-    key_list <- c ('landuse', 'leisure', 'natural', 'natural')
+    values <- rep ("", length (keys))
+    val_list <- c ("grass", "park", "tree", "water")
+    key_list <- c ("landuse", "leisure", "natural", "natural")
 
     for (i in seq (val_list))
-        if (any (structures == val_list [i]))
-        {
+        if (any (structures == val_list [i])) {
+
             keys [structures == val_list [i]] <- key_list [i]
             values [structures == val_list [i]] <- val_list [i]
         }
 
-    return (list ('keys' = keys, 'values' = values))
+    return (list ("keys" = keys, "values" = values))
 }
 
-get_dark_cols <- function ()
-{
+get_dark_cols <- function () {
+
     list (
-          col_bg = 'gray20',
+          col_bg = "gray20",
           col_green = rgb (100, 120, 100, 255, maxColorValue = 255),
           col_green_bright = rgb (100, 160, 100, 255, maxColorValue = 255),
           col_blue = rgb (100, 100, 120, 255, maxColorValue = 255),
@@ -99,10 +100,10 @@ get_dark_cols <- function ()
           )
 }
 
-get_light_cols <- function ()
-{
+get_light_cols <- function () {
+
     list (
-          col_bg = 'gray95',
+          col_bg = "gray95",
           col_green = rgb (200, 220, 200, 255, maxColorValue = 255),
           col_green_bright = rgb (200, 255, 200, 255, maxColorValue = 255),
           col_blue = rgb (200, 200, 220, 255, maxColorValue = 255),
@@ -113,43 +114,43 @@ get_light_cols <- function ()
           )
 }
 
-set_cols <- function (col_scheme, structures)
-{
+set_cols <- function (col_scheme, structures) {
+
     cols <- rep (col_scheme$col_bg, length (structures))
-    cols [structures == 'building'] <- col_scheme$col_gray1
-    cols [structures == 'amenity'] <- col_scheme$col_gray2
-    cols [structures == 'waterway'] <- col_scheme$col_blue
-    cols [structures == 'natural'] <- col_scheme$col_green
-    cols [structures == 'park'] <- col_scheme$col_green
-    cols [structures == 'tree'] <- col_scheme$col_green_bright
-    cols [structures == 'grass'] <- col_scheme$col_green_bright
-    cols [structures == 'highway'] <- col_scheme$col_black
-    cols [structures == 'boundary'] <- col_scheme$col_white
+    cols [structures == "building"] <- col_scheme$col_gray1
+    cols [structures == "amenity"] <- col_scheme$col_gray2
+    cols [structures == "waterway"] <- col_scheme$col_blue
+    cols [structures == "natural"] <- col_scheme$col_green
+    cols [structures == "park"] <- col_scheme$col_green
+    cols [structures == "tree"] <- col_scheme$col_green_bright
+    cols [structures == "grass"] <- col_scheme$col_green_bright
+    cols [structures == "highway"] <- col_scheme$col_black
+    cols [structures == "boundary"] <- col_scheme$col_white
 
     return (cols)
 }
 
 # Extend suffixes until sufficiently many letters are included for entries to
 # become unique.
-unique_suffixes <- function (sfx, structures, indx_in)
-{
+unique_suffixes <- function (sfx, structures, indx_in) {
+
     matches <- sapply (sfx, function (x) which (sfx %in% x))
     nletts <- rep (2, length (matches))
     # This while loop will always stop because it is only applied to unique
     # values
-    while (max (sapply (matches, length)) > 1)
-    {
+    while (max (sapply (matches, length)) > 1) {
+
         matches_red <- list ()
         for (i in seq (matches))
             if (length (matches [[i]]) > 1 &
                 !all (matches [[i]] %in% unlist (matches_red)))
                 matches_red [[length (matches_red) + 1]] <- matches [[i]]
-        for (i in seq (matches_red))
-        {
-            repls <- structures [indx_in] [matches_red [[i]] ]
-            sfx [matches_red [[i]] ] <- toupper (substr (repls, 1,
-                                                nletts [matches_red [[i]] ]))
-            nletts [matches_red [[i]] ] <- nletts [matches_red [[i]] ] + 1
+        for (i in seq (matches_red)) {
+
+            repls <- structures [indx_in] [matches_red [[i]] ]                  # nolint
+            sfx [matches_red [[i]] ] <- toupper (substr (repls, 1,              # nolint
+                                                nletts [matches_red [[i]] ]))   # nolint
+            nletts [matches_red [[i]] ] <- nletts [matches_red [[i]] ] + 1      # nolint
         }
         matches <- sapply (sfx, function (x) which (sfx %in% x))
     }
@@ -159,8 +160,8 @@ unique_suffixes <- function (sfx, structures, indx_in)
 
 # Extend list of unique suffixes to the full structures with duplicates. This
 # is a bit tricky, and is done by first creating an index of all duplicates:
-extend_suffixes <- function (sfx, structures, indx_in, indx_out)
-{
+extend_suffixes <- function (sfx, structures, indx_in, indx_out) {
+
     indx <- which (duplicated (structures) |
                    duplicated (structures, fromLast = TRUE))
     # Then the values of that indx that are not in indx_out
@@ -168,8 +169,8 @@ extend_suffixes <- function (sfx, structures, indx_in, indx_out)
     # And those two can be matched for the desired replacement
     suffixes <- rep (NULL, length (structures))
     suffixes [indx_in] <- sfx
-    for (i in indx)
-    {
+    for (i in indx) {
+
         ii <- which (structures == structures [i])
         suffixes [ii] <- suffixes [i]
     }
